# pydokus

pydokus is Python module for interacting with the Dokus REST API. Dokus is a 
Norwegian web app for invoicing and timetracking, see https://dokus.no for 
more information.

## Installation

Install `pydokus`:

	pip install pydokus

Alternatively, download the source code and manually add it to your `PYTHONPATH`.

## Usage

See the `sample.py` file for usage examples. For further documentation, please
refer to the [GitHub Wiki](https://github.com/funkbit/dokus-api/wiki).
